@@ -9,7 +9,7 @@ module Adapters
   # `#adapter_options` optional. extra arguments for building an adapter
   module Integration
     def self.apply(base, *extra_features)
-      if base.live_server?
+      if base.live_server
         features = [:Common]
         features.concat extra_features
         features << :SSL if base.ssl_mode?
@@ -18,6 +18,7 @@ module Adapters
       elsif !defined? @warned
         warn "Warning: Not running integration tests against a live server."
         warn "Start the server `ruby test/live_server.rb` and set the LIVE=1 env variable."
+        warn "See CONTRIBUTING for usage."
         @warned = true
       end
     end
@@ -114,6 +115,11 @@ module Adapters
         assert_equal expected, get('ssl').body
       end
 
+      def test_GET_reason_phrase
+        response = get('echo')
+        assert_equal "OK", response.reason_phrase
+      end
+
       def test_POST_send_url_encoded_params
         assert_equal %(post {"name"=>"zack"}), post('echo', :name => 'zack').body
       end
