@@ -7,8 +7,7 @@ module Adapters
 
     def adapter() :net_http end
 
-    behaviors = [:NonParallel]
-    behaviors << :Compression if RUBY_VERSION >= '1.9'
+    behaviors = [:NonParallel, :Compression]
 
     Integration.apply(self, *behaviors)
 
@@ -41,5 +40,17 @@ module Adapters
       assert_equal 1234, http.port
     end
 
+    def test_custom_adapter_config
+      url = URI('https://example.com:1234')
+
+      adapter = Faraday::Adapter::NetHttp.new do |http|
+        http.continue_timeout = 123
+      end
+
+      http = adapter.net_http_connection(:url => url, :request => {})
+      adapter.configure_request(http, {})
+
+      assert_equal 123, http.continue_timeout
+    end
   end
 end
