@@ -9,7 +9,7 @@ class EnvTest < Faraday::TestCase
     @conn.options.timeout      = 3
     @conn.options.open_timeout = 5
     @conn.ssl.verify           = false
-    @conn.proxy 'http://proxy.com'
+    @conn.proxy = 'http://proxy.com'
   end
 
   def test_request_create_stores_method
@@ -24,6 +24,13 @@ class EnvTest < Faraday::TestCase
     assert_equal 'http://sushi.com/api/foo.json?a=1', env.url.to_s
   end
 
+  def test_request_create_stores_uri_with_anchor
+    env = make_env do |req|
+      req.url 'foo.json?b=2&a=1#qqq'
+    end
+    assert_equal 'http://sushi.com/api/foo.json?a=1&b=2', env.url.to_s
+  end
+
   def test_request_create_stores_headers
     env = make_env do |req|
       req['Server'] = 'Faraday'
@@ -51,10 +58,16 @@ class EnvTest < Faraday::TestCase
       req.options.timeout = 10
       req.options.boundary = 'boo'
       req.options.oauth[:consumer_secret] = 'xyz'
+      req.options.context = {
+          foo: 'foo',
+          bar: 'bar'
+      }
     end
+
     assert_equal 10, env.request.timeout
     assert_equal 5, env.request.open_timeout
     assert_equal 'boo', env.request.boundary
+    assert_equal env.request.context, { foo: 'foo', bar: 'bar' }
 
     oauth_expected = {:consumer_secret => 'xyz', :consumer_key => 'anonymous'}
     assert_equal oauth_expected, env.request.oauth
@@ -65,11 +78,6 @@ class EnvTest < Faraday::TestCase
     assert_equal false, env.ssl.verify
   end
 
-  def test_request_create_stores_proxy_options
-    env = make_env
-    assert_equal 'proxy.com', env.request.proxy.host
-  end
-
   def test_custom_members_are_retained
     env = make_env
     env[:foo] = "custom 1"
@@ -135,7 +143,7 @@ class HeadersTest < Faraday::TestCase
     assert_equal 'application/json', @headers.delete('content-type')
     assert_equal 0, @headers.size
     assert !@headers.include?('content-type')
-    assert_equal nil, @headers.delete('content-type')
+    assert_nil @headers.delete('content-type')
   end
 
   def test_parse_response_headers_leaves_http_status_line_out
